### A Pluto.jl notebook ###
# v0.19.40

using Markdown
using InteractiveUtils

# This Pluto notebook uses @bind for interactivity. When running this notebook outside of Pluto, the following 'mock version' of @bind gives bound variables a default value (instead of an error).
macro bind(def, element)
    quote
        local iv = try Base.loaded_modules[Base.PkgId(Base.UUID("6e696c72-6542-2067-7265-42206c756150"), "AbstractPlutoDingetjes")].Bonds.initial_value catch; b -> missing; end
        local el = $(esc(element))
        global $(esc(def)) = Core.applicable(Base.get, el) ? Base.get(el) : iv(el)
        el
    end
end

# ╔═╡ a145e2fe-a903-11eb-160f-df7ea83fa3e6
begin
	using PlotlyBase, HypertextLiteral, PlutoUI, NLsolve, PlutoPlotly
	#import PlotlyJS:savefig
end

# ╔═╡ 943edb36-acc8-4b2a-94ab-c544f9eb279b
md"""
# Week 9 - Macroeconomic Policy: the AD/AS/MP Model

# Exercises

**Macroeconomics, ISCTE-IUL**
"""

# ╔═╡ 1245aef9-18ce-42f5-af82-c2e6cce70798
md"""
**Vivaldo Mendes, Ricardo Gouveia-Mendes, Luís Clemente-Casinhas; April 2024**
"""

# ╔═╡ 4618a663-f77e-4ccc-9b00-e84dbd5beb34
md"""
### Packages
"""

# ╔═╡ 74de9f66-d5b4-4e0f-a75d-5177b1842191
begin
	function Base.show(io::IO, mimetype::MIME"text/html", plt::PlotlyBase.Plot)
       # Remove responsive flag on the plot as we handle responsibity via ResizeObeserver and leaving it on makes the div flickr during updates
	hasproperty(plt,:config) && plt.config.responsive && (plt.config.responsive = false)   
	show(io,mimetype, @htl("""
			<div>
			<script id=asdf>
			const {plotly} = await import("https://cdn.plot.ly/plotly-2.2.0.min.js")
			const PLOT = this ?? document.createElement("div");
		

		
			Plotly.react(PLOT, $(HypertextLiteral.JavaScript(PlotlyBase.json(plt))));


		
			const pluto_output = currentScript.parentElement.closest('pluto-output')

			const resizeObserver = new ResizeObserver(entries => {
				Plotly.Plots.resize(PLOT)
			})

			resizeObserver.observe(pluto_output)

			invalidation.then(() => {
				resizeObserver.disconnect()
			})
		
			return PLOT
			</script>
			</div>
	"""))
	end
end

# ╔═╡ 69d5adb8-c5fd-4fd9-875d-cc4c25af0125
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ 0bc2eb14-3b5a-4203-82dd-3ef2044a2c93
md"""
## Exercise 1. Divine coincidence
"""

# ╔═╡ 5999a598-0408-44f1-bd33-c4d0fa5a6006
md"""

Olivier Blanchard, a former MIT professor and IMF Chief Economist, wrote this in 2016:

>*"In the benchmark [macroeconomic] model, stabilizing inflation keeps the unemployment rate at the natural rate, and the natural rate in turn is the best rate that can be achieved by policy. Jordí Gali and I have called this proposition the **“divine coincidence”**.*

[Olivier Blanchard (2016)](https://www.piie.com/publications/pb/pb16-1.pdf)

👉 a) How do we represent the term "divine coincidence" as a set of conditions that describe society's best possible outcome in our model?

👉 b) Do you consider that, i.e., a 10% unemployment rate may be reasonably acceptable as "natural"?

"""

# ╔═╡ 5ceac821-7004-4764-b2ee-b9e2aa0f6fdf
md"""
!!! answer "Answer (a)"

	Here

"""

# ╔═╡ 450dec57-18a3-4031-bf36-36a422d0fd34
md"""
!!! tip "Answer (b)"

	Here

"""

# ╔═╡ eb74f385-1688-45ea-8ad1-11bce1e48f87
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ c90e721d-f4ca-473c-8a7c-7159d66d81cf
md"""
## Exercise 2. The Fed's dual mandate
"""

# ╔═╡ 4b6af178-725d-4841-8d62-102c561428c6
md"""
>*"In conducting monetary policy, we will remain highly focused on fostering as strong a labor market as possible for the benefit of all Americans. And we will steadfastly seek to achieve a 2 percent inflation rate over time." Chair Jerome Powell, Aug. 27, 2020 speech* [here](https://www.federalreserve.gov/newsevents/speech/powell20200827a.htm)

The sentence above by the Fed's Chair highlights the two main goals of the Fed. What are those two goals?
"""

# ╔═╡ bd22c100-271d-4496-a55f-792f0f92117f
md"""
!!! answer

	Here

"""

# ╔═╡ 21d4988a-e438-4562-bc8f-a1d847020e25
md"""
## Exercise 3. Why 2% inflation?

"""

# ╔═╡ afeda154-0ce5-4e1b-9e12-24420dd72681
md"""

**Is 2% Really the Right Inflation Target for Central Banks?, Project Syndicate, July 27, 2020.** Michael J. Boskin, a Professor of Economics at Stanford University and a former Chairman of George H.W. Bush’s Council of Economic Advisers, provided this answer: 

>*"Winston Churchill famously quipped that “democracy is the worst form of government except for all the other forms that have been tried.” The same logic applies to advanced-economy central banks’ inflation targets: compared to anything higher or lower (by a non-trivial margin), 2% is likely to be better."*

"""

# ╔═╡ 08203cfc-1ede-432b-b81c-f0a5cbaa5816
md"""
👉 a) Why do central banks have a target level for the inflation rate?
"""

# ╔═╡ 40913213-c3f7-4dd7-9ffa-c1390f80c099
md"""
!!! answer "Answer (a)"

	Here

"""

# ╔═╡ c49227b4-af6d-4c5b-a2fb-ffd15b1c84b8
md"""
👉 b) Why a target of 2%?
"""

# ╔═╡ b6e384ad-f8fb-434c-944a-91ac9f729068
md"""
!!! answer "Answer (b)"

	Here

"""

# ╔═╡ ec759c26-25d0-4554-96ea-665f6b694204
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ c38dbe18-a85a-4960-9c99-674196e0526d
md"""
## Exercise 4. The Fed's response to shocks

"""

# ╔═╡ cb0d6593-5ca4-4afd-bddc-88506c4cf477
md"""
From the [FRB of New York](https://www.newyorkfed.org/markets/reference-rates/effr) we can download the figure below, where we can see the range for the Fed's nominal interest rate target value. The chosen period is from May 2008 to November 2022. The shaded interval show three main types of decisions by the Fed: (i) keep the range unchanged, (ii) small and gradual changes in the range, and (iii) dramatic changes in at least three occasions. 

👉 a) Can we associate different magnitudes of shocks to these policy decisions?

👉 b) Can we see a "Zero Lower Bound" (ZLB) on nominal interest rates in the figure? How likely is it to be found over the last fifteen years or so? 
"""

# ╔═╡ 35612933-4d9a-4b88-b40f-3a2eec3a20fa
Resource("https://vivaldomendes.org/images/depot/FFR.png", :width=>800)

# ╔═╡ 6b39a08d-9f0d-4e46-9f63-549d7eb15c05
md"""
!!! answer "Answer (a)"

	Here

"""

# ╔═╡ d72389b4-b317-4d1a-928a-c002822ed785
md"""
!!! answer "Answer (b)"

	Here

"""

# ╔═╡ f20bd50f-8096-4169-b4ed-bd107fa2537a
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ add07024-b7eb-445d-b4f4-6a6757c2ecd3
md"""
## Exercise 5. Macroeconomic equilibrium
"""

# ╔═╡ 8e2203e6-6677-47b9-8032-e9c63c0f41bb
md"""
Consider the four fundamental functions that allow us to analyze the entire functioning of the economy:

$$\begin{align*}
\text{AD}: \quad Y &=m \cdot \overline{A}-m \cdot \phi \cdot(\overline{r}+\lambda \pi) \\[3mm]           
\text{AS}: \quad  \pi &=\pi^{e}+\gamma\left(Y-Y^{P}\right)+\rho \\[3mm]  
\text{MP}: \quad r&=\overline{r}+\lambda \pi \\[3mm]  
\text{Fisher Eq.}: \quad i& =r +\pi
\end{align*}$$

and the following information concerning exogenous variables and parameters:

$$\begin{aligned}
&\overline{A}=7.6 \ , \ m=2.0 \ , \ \phi=0.2 \ , \ \overline{r}=2.0 \ , \ \lambda=0.5 \ , \ \pi^{e}=2.0 \ , \ \gamma= 4.5 \ , \ Y^{P}=14.0 \ , \ \rho=0.
\end{aligned}$$

👉 a) Calculate the short-run equilibrium values for the inflation rate, the level of GDP, the real interest rate, as well as the nominal interest rate. Represent graphically, involving the AD and AS curves.

👉 b) The graphical representation of of the initial equilibrium is presented in Figure 2 below. Is the economy in a recession or an economic boom? Justify.

👉 c) If there is no demand or supply shock, what will happen to the economy over time?

"""

# ╔═╡ 0fe4de49-3687-4900-a691-334cca6dd3c6
md"""
Before we answer the questions above, we have yo pass the information about parameters and exogenous variables into the notebook:
"""

# ╔═╡ a77a222e-aba3-4ac6-a5b0-a7551e3ccce4
begin
	
	Ā5 = 7.6 ; λ5 = 0.5 ; m5 = 2.0 ; ϕ5 = 0.2 ;	r̄5 = 2.0 	# Demand-side parameters and exogenous variables	
	
	γ5 = 4.5 ; Yᴾ5 = 14.0 ; πᵉ5 = 2.0 ; ρ5 = 0.0 			# Supply-side parameters and exogenous variables				
end;

# ╔═╡ 74ee6d92-ef34-47ce-8d57-39d41474a11d
md"""
!!! note
	Note that the $\left\{\pi^{e}, \overline{r}, r, i, \rho \right\}$ are rates and are measured in percentage points (e.g., $2.0$ means $2.0\%$), while $\{Y, Y^P , \overline{A}\}$ are measured in trillion dollars. In the solutions below, to avoid doubt, we put the symbol % only at the final step of the solutions.

	This exercise is a continuation of Exercise 5 of the previous week by adding a new curve: the MP curve. The solution will follow the same steps, but it will have to calculate the values of two new variables: the real interest rate and the nominal interest rate.
"""

# ╔═╡ 3aba8dac-7fa0-4193-9f41-ff8d9a49230f
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ 40d80d26-e808-43bf-833e-d1bb07b57630
md"""
#### Solution using NLsolve
"""

# ╔═╡ 1b2dba45-7fbc-4658-9a02-1c54511f650a


# ╔═╡ 6a9080ad-2117-4e8e-86b4-4c3a737b989b


# ╔═╡ fc550324-0ffd-4039-b92e-67f12b6b8c90
md"""
!!! tip "Answer (a)"


	Here


"""

# ╔═╡ 7ae85983-ee8e-4dd3-a7bf-474aaf74863c
md"""
!!! answer "Answer (b)"

	Here

"""

# ╔═╡ a54b4a9b-a752-454f-af38-87ec1115512a
md"""
!!! answer "Answer (c)"

	Here

"""

# ╔═╡ 445f88ea-3c01-4939-a2bc-a1c139213b17
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ 9b54c17b-e835-4478-95ae-a9e2d5de9f59
md"""
## Exercise 6. A positive demand shock
"""

# ╔═╡ 7f7ca57b-5774-4184-8026-32ad0f56cb39
md"""

Suppose the government, to stimulate economic activity, increases its spending on goods and services (G&S) by 0.2 trillion dollars. This decision is considered a demand shock and will have short-run and long-run impacts. To answer the following questions, use the slider `ΔĀ5` and the figures below.

👉 (a) Using the slider `ΔĀ6` and Fig. 3 and 4 below, describe the short-term impact of this shock on GDP, inflation, and the real interest rate.

"""

# ╔═╡ 7e47b3bc-a45c-4d84-9a58-d4f01d6ba99f
md"""
`ΔĀ6 = `$(@bind ΔĀ6 Slider(-1.0:0.05:1.0, default=0.0, show_value=true))
"""

# ╔═╡ 704145a9-ef2e-48ad-bbe2-b6bc750d62fc
md"""
!!! answer "Answer (a)"

	Here

"""

# ╔═╡ 13b03571-e332-46f7-83d7-4a41fbcca0b5
md"""
👉 (b) What will be the long-run equilibrium that results from this shock? Give the values of GDP, the inflation rate, real and nominal interest rates. To answer these questions, use the slider `self_correction6` and Fig. 5 and 6 below.
"""

# ╔═╡ 0941b1d5-b354-4857-9264-fcd2744e03a6
md"""
!!! hint
	Move the slider `self_correction6` so the new long-term equilibrium will be correctly represented in the figures below.
"""

# ╔═╡ 63fb8be4-f6ce-457b-8d0c-b359f959f5a6
md"""
`self_correction6 = `$(@bind self_correction6 Slider(-4.0:0.5:4.0, default=0.0, show_value=true))
"""

# ╔═╡ 979c128b-76ed-4c28-b3ad-ffbbac481414
md"""
!!! answer "Answer (b)"

	Here
	
"""

# ╔═╡ e69deaa4-bb1f-454b-9296-598a9b9271a0


# ╔═╡ 1072c4ef-b41f-4de8-a64d-3cdaecf8949d
md"""
👉 (c) Solve for the new long-term equilibrium using the NLsolve method.
"""

# ╔═╡ 1d0765df-9ee8-4e65-a0d1-bc3e54940846
md"""
!!! hint 
	To answer this question, we have to add the `self_correction6` term to the AD curve and the initial shock `ΔĀ5` to the AD curve, previously written in exercise 4.
"""

# ╔═╡ 0252b84b-8411-4145-81ee-3e90892d859f


# ╔═╡ e6262829-bfe3-4030-9158-28a37c13fc1a


# ╔═╡ 9cefbcc6-397b-48d9-810b-05937873184a
md"""
!!! answer "Answer (c)"
	
	Here

"""

# ╔═╡ 3aca9c62-a1e3-4478-a8a5-29d19535ad75
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ dcd13560-0f73-4aaa-b59a-b7961d8cdc63
md"""
## Exercise 7. A positive supply shock
"""

# ╔═╡ 7f67d656-bb55-4097-ba49-10140f9b3502
md"""
Consider the same values for the parameters and the exogenous variables of Exercise 5. However, due to a sharp decline in oil prices, there is a positive supply shock such that now we will have $\rho = -1.9$. 

👉 a) Using the slider `ρ7` below, calculate the short-run equilibrium values for the inflation rate, the level of GDP, the real interest rate, and the nominal interest rate resulting from such a shock. Represent graphically, involving the AD/AS and the MP curves.

"""

# ╔═╡ fe1e6cbc-db87-40ac-836d-68069615c133
md"""
!!! hint 
	Move the slider `ρ6` so the new equilibrium will be correctly represented in the figures below.
"""

# ╔═╡ 22fd1017-4015-407d-bd79-188a763e87a4
md"""
`ρ7  = `$(@bind ρ7  Slider(-3.0:0.1:3.0, default=0.0, show_value=true))
"""

# ╔═╡ f21a5ae9-7887-4cf1-83f9-f1f0a0b3d5b3
md"""
!!! tip "Answer (a)"

	Here
	
"""

# ╔═╡ 7beabfcd-9cbb-4eac-8bdb-298b60f541ac
md"""
👉 b) Is the economy in a recession or a boom? Justify.
"""

# ╔═╡ 28052403-f02e-41dc-ba74-e42d88f3d494
md"""
!!! tip "Answer (b)"

	Here

"""

# ╔═╡ 70e7a7ef-d49d-417e-8f87-ed9870857b45
md"""
👉 c) If there are no other supply or demand shocks, what will happen to the economy over time? Answer this question by manipulating the slider `self_correction7` below.
"""

# ╔═╡ db702f28-e3e7-4d14-9209-1cbe2917247b
md"""
`self_correction7 = `$(@bind self_correction7 Slider(-4.0:0.1:4.0, default=0.0, show_value=true))
"""

# ╔═╡ 5859e1fa-f4ef-42b7-a3fd-5085cd64161c
md"""
!!! tip "Answer (c)"

	Here

"""

# ╔═╡ 933a7956-1037-401e-a0cd-e42ec8eeec2d
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ ec34cbc5-fda5-4792-adc8-3bb0d02a7f22
md"""
## Exercise 8. A permanent postive supply shock
"""

# ╔═╡ 83c030a3-28bc-419f-968b-62ce9ab0a1e4
md"""
Consider the same data as in Exercise 5. However, suppose the supply shock is **permanent** instead of temporary (like in the previous exercise); oil prices go down, and then they will stay there for an extended period. This positive shock will cause Potential GDP to increase by 0.2 trillion dollars. 

How would we change our answers to the three questions raised in the previous exercise? Use the slider `self_correction8` to answer this exercise.
"""

# ╔═╡ ab9daba1-be70-4e7f-8304-639db1c16d2c
md"""
`self_correction8 = `$(@bind self_correction8 Slider(-4.0:0.1:4.0, default=0.0, show_value=true))
"""

# ╔═╡ 79d2fb58-371b-4720-976c-d5f6a70e46c6
md"""
!!! answer

	Here

"""

# ╔═╡ a8bfdb49-6a0a-448a-b84e-b5040f8a40c9
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ df3e386a-66f1-4525-b09d-a605c24aff21
md"""
## Appendix 1. More on the natural unemployment rate
"""

# ╔═╡ 4a1e9746-51d3-4981-b685-2d1545fb2a07
md"""
!!! note

	This Appendix is considered to be of interest only to those students who have a particular interest in macroeconomic controversies.

"""

# ╔═╡ 15c7a983-f8d3-44a5-a08a-7426dcee7639
md"""
Do you consider that, i.e., a 10% unemployment rate may be reasonably acceptable as "natural"?
"""

# ╔═╡ e1ad4f38-80cf-4730-9f5e-1a0c021becff
md"""
!!! answer

	It depends; it turns out to be more a political opinion than a scientific one. We have two basic types of unemployment: natural unemployment (=structural + frictional) and cyclical unemployment (which depends on the cycles of economic activity). Economic policy can affect cyclical unemployment (everybody agrees) but can do very little to affect structural and frictional unemployment (some agree, some disagree).

	Why the disagreement? Because people have political views, and putting them behind "structural unemployment" is possible. For example, Narayana Kocherlakota (a former President of the Federal Reserve Bank of Minneapolis and Professor at Stanford University) made a famous speech in 2010, [Inside the FOMC:](https://www.minneapolisfed.org/speeches/2010/inside-the-fomc)

	>*"What does this change in the relationship between job openings and unemployment connote? In a word, mismatch. Firms have jobs but can’t find appropriate workers. The workers want to work but can’t find appropriate jobs. [...] Of course, the key question is: How much of the current unemployment rate is really due to mismatch, as opposed to conditions that the Fed can readily ameliorate? The answer **seems to be a lot**. I mentioned that the relationship between unemployment and job openings was stable from December 2000 through June 2008. Were that stable relationship still in place today, and given the current job opening rate of 2.2 percent, we would have an unemployment rate of closer to 6.5 percent, not 9.5 percent. **Most of the existing unemployment represents mismatch that is not readily amenable to monetary policy**."*(our emphasis)

	This view is defended by Classical economists, who stress that economic policy can do very little to fight structural unemployment. Keynesian economists question such a view because they argue that empirical evidence can easily refute the Classical argument. In the US, looking at the figure below, how is it possible that in just ten years, the unemployment rate was 4.4% in mid-2007 (in the middle of a downward process), jumped to 10% in October 2009, to go back to 4.4% in May 2017? The Keynesian question is: "What changed so structurally in the labor market throughout those ten years to explain that behavior of unemployment in the US economy?"

	The two views are antagonistic, and in macroeconomics, it is vital to understand the logic behind each one before choosing sides. Therefore, considering the initial question, for the Classicals, an unemployment rate of 10% can be perfectly acceptable as "natural," and the Fed can do nothing to change it. At the same time, there is nothing "natural" in such a number for the Keynesians, but rather a sign of a drastic collapse in aggregate demand, which the central bank policy can quickly reverse.


"""

# ╔═╡ 34f82c93-1bad-4635-8e5f-3e9960657429
Resource("http://ebs.de.iscte.pt/UnemploymentUS.png", :width=>900)

# ╔═╡ 6b4249b9-8d60-4547-b416-fe2a21c8f33c
md"""
____________________________________________________________________________________________________________
"""

# ╔═╡ 26fe310e-9ed8-4d09-bb82-a5bd39193dde
md"""
# Reality Check
"""

# ╔═╡ 63e8392d-c2b3-4a1a-b9f1-2acffe23ecb4
md"""
## Application 1

### The Volcker Disinflation, 1980–1986
"""

# ╔═╡ 3bed5d29-9973-4990-961a-53e53451854e
md"""
*On page 309 in the textbook:*

"When Paul Volcker became the chairman of the Federal Reserve in August 1979, inflation had spun out of control and the inflation rate exceeded 10%. Volcker was determined to get inflation down. By early 1981, the Federal Reserve had raised the federal funds rate to over 20%, which led to a sharp increase in real interest rates. Volcker was indeed successful in bringing inflation down, [as the table below exposes indicates], with the inflation rate falling from 13.5% in 1980 to 1.9% in 1986. The decline in inflation came at a high cost: the economy experienced the worst recession up to that time since World War II, with the unemployment rate soaring to 9.7% in 1982."

$\begin{array}{lcc}
\text { Year } & \text {Unemp. Rate (\%)} & \text { Inflation (\%) } \\
\hline 1980 & 7.1 & 13.5 \\
1981 & 7.6 & 10.3 \\
1982 & 9.7 & 6.2 \\
1983 & 9.6 & 3.2 \\
1984 & 7.5 & 4.3 \\
1985 & 7.2 & 3.6 \\
1986 & 7.0 & 1.9
\end{array}$

**Can we explain that sharp decline in inflation using our AD/AS/MP model?**
"""

# ╔═╡ de32bd19-9ef4-45f2-96cd-3a9675d9527d
md"""
# Auxiliary cells (do not delete)
"""

# ╔═╡ 9fa87191-7c90-4738-a45a-acd929c8bd1b
  TableOfContents()

# ╔═╡ 31cef45f-d6ea-4c0d-b58f-11ae0988a001
md"### CSS code"

# ╔═╡ 18101821-af97-41b3-b77e-6ff28ef91568
html"""
<style>
	@media screen {
		main {
			margin: 0 auto;
			max-width: 1650px;
    		padding-left: max(100px, 10%);
    		padding-right: max(380px, 10%); 
            # 383px to accommodate TableOfContents(aside=true)
		}
	}
</style>
"""

# ╔═╡ c2eeacf8-99f0-4a5e-83ac-7bcc6f0e5f22
# html"""<style>main {    max-width: 950px;    align-self: flex-start;    margin-left: 600px;}"""

# ╔═╡ 45c90777-16b2-4359-9afa-31fdaf23fd73
md"""
##### Exercise 5. Supporting cells
"""

# ╔═╡ 99b637d3-af40-4132-aa5b-d0d386b8d11a
begin
	πd_max5 = (Ā5 / (λ5 * ϕ5)) - r̄5/λ5       							 # The AD curve y-axis' intercept
	
	πs_min5 = πᵉ5 - γ5 * Yᴾ5 + ρ5           							  # The AS curve y-axis' intercept
end;

# ╔═╡ 0ed308d6-1457-4571-9898-d6fe23ca827f
begin
	Y5 = 12.0:0.01:15.0
	
	πd5 = πd_max5 .- ((1 ./(m5 .* ϕ5 .* λ5)) .* Y5) # AD function
	πs5 = πs_min5 .+ γ5 .*Y5             # AS function
	
	trace9_0 = scatter(; x = [14,14] , y = [-7,14] , mode = "line", line_width = "4", name = "Yp", 
					line_color = "Orange")
	
	trace9_1 = scatter(; x = Y5, y = πd5, mode="lines" , line_color = "Blue", line_width = "3",
			name  = "AD")
	
	trace9_2 = scatter(; x = Y5, y = πs5, mode="lines" , line_color = "Red", line_width = "3",
					name  = "AS")
	
	trace9_3 = scatter(; x = [14.0], y = [2.0], text =["1"], 
					textposition = "top center", name ="Eq1", mode="markers+text", marker_size= "12",
					marker_color="Blue", textcolor = "Black",
	 				textfont = attr(family="sans serif", size=18, color="black"))
	
	
	layout9_3 = Layout(;
					title_text = "Fig 2. Macroeconomic Equilibrium",
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" GDP trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [13.5, 14.5],	
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-0.5 , 4.5])

	p9_3 = Plot([trace9_0, trace9_1, trace9_2, trace9_3], layout9_3)
	
end;

# ╔═╡ 1f24f76d-6f4e-4031-8d62-41b0ec351a2c
begin
	#function fig9_2()
		r5 = 0.0:0.01:5.0
	
		πmp5 = - (r̄5 ./ λ5) .+  r5 ./ λ5 
		
		trace4_0 = scatter(; x = r5, y = πmp5, mode="lines" , line_color = "Brown", line_width = "3",
				name  = "MP")
		
		trace4_1 = scatter(; x = [3.0], y = [2.0], text =["1"], 
						textposition = "top center", name ="Eq1", mode="markers+text", 
						marker_size= "12", marker_color="Brown", 
						textfont = attr(family="sans serif", size=18, color="black"))
		
		layout4_1 = Layout(;
						title_text = "Fig 1. MP Function",
						title_x = 0.5,
						hovermode = "x",
	                    xaxis=attr(title=" Real interest rate (r)", showgrid=true, zeroline=false),
	                    xaxis_range = [1.6, 4.2],
						xaxis_tickvals = [2, 2.5, 3, 3.5, 4, 4.5],
	                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
						yaxis_range=[-0.5 , 4.5])
	
	   p4_1 = Plot([trace4_0, trace4_1], layout4_1)
	#end
end;

# ╔═╡ 6e92b539-a91d-410f-a895-8d4b51b5257b
begin
	p02 =[p4_1 p9_3]
end

# ╔═╡ 62b870d7-80a7-46ea-b784-579d5ad289c2
md"""
##### Exercise 6. Supporting cells
"""

# ╔═╡ 43e8fd65-2d3a-41bc-a8d6-44cf412318ed
begin
	Y5_ΔĀ6 = 12.0:0.02:15.0
	
	πd_max5_ΔĀ6 = ((Ā5 .+ ΔĀ6) ./ (λ5 .* ϕ5)) .- r̄5 ./ λ5 # New max value of the AD function
	
	πd5_ΔĀ6 = πd_max5_ΔĀ6 .- ((1 ./(m5 .* ϕ5 .* λ5)) .* Y5_ΔĀ6) # AD function
	
	trace9_4 = scatter(; x = Y5_ΔĀ6, y = πd5_ΔĀ6, mode="lines" , line_color = "Magenta", 
					 line_width = "3", name  = "AD2")
		
	trace9_5 = scatter(; x = [14.21], y = [2.947], text =["2"], 
					textposition = "top center", name ="Eq2", mode="markers+text", 
					marker_size= "12", marker_color="Magenta",
					textfont = attr(family="sans serif", size=16, color="black"))
	
	
	layout9_5 = Layout(;
					title_text ="Fig 4. A Positive Demand Shock",
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" GDP trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [13.6, 14.5],	
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-0 , 5])

   p9_4 = Plot([trace9_0, trace9_1, trace9_2, trace9_4, trace9_3, trace9_5], layout9_5)
	
end;

# ╔═╡ 955e1066-8468-4553-b834-f21116d4a594
begin
	
	trace4_3 = scatter(; x = [3.473], y = [2.946], text =["2"], 
					textposition = "top center", name ="Eq2", mode="markers+text", 
					marker_size= "12", marker_color="Brown", 
					textfont = attr(family="sans serif", size=16, color="black"))
	
	layout4_3 = Layout(;
					title_text ="Fig 3. MP Function",
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title= "Real interest rate (r)", showgrid=true, zeroline=false),
                    xaxis_range = [2.0, 4.5],
					xaxis_tickvals = [2, 2.5, 3, 3.5, 4, 4.5],
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-0 , 5])
	
	p4_3 = Plot([trace4_0, trace4_1,trace4_3], layout4_3)
end;

# ╔═╡ 5c2ce460-bd7a-4355-8b11-d8e6896d973d
begin
	p03 =[p4_3 p9_4]
end

# ╔═╡ df2a5996-55a7-4883-ac2f-59d4cce2c129
begin
	Y5_self = 12.0:0.01:15.0
	
	πs5_self = πs_min5 .+ γ5 .*Y5_self .+ self_correction6            # AS function
	
	trace9_6 = scatter(; x = Y5_self, y = πs5_self, mode="lines" , line_color = "Coral", line_width = "3",
			name  = "AS2")	
	
	trace9_7 = scatter(; x = [14.0], y = [4.0], text =["3"], textposition = "top center", 
					name ="Eq3", mode="markers+text", marker_size= "12", marker_color="Coral", 
					textfont = attr(family="sans serif", size=18, color="black"))
	
	
	layout9_6 = Layout(;
					title_text = "Fig 6. A Positive Demand Shock",
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" GDP trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [13.6, 14.5],	
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[1 , 5])
	

    p9_6 = Plot([trace9_0,trace9_1,trace9_2,trace9_4, trace9_6, trace9_3, trace9_5,trace9_7], layout9_6)
	
end;

# ╔═╡ e1fc276a-db60-4de2-b21e-4e6bfcdbe6e2
begin
	
	trace4_4 = scatter(; x = [4.0], y = [4.0], text =["3"], 
					textposition = "top center", name ="Eq3", mode="markers+text", 
					marker_size= "12", marker_color="Brown", 
					textfont = attr(family="sans serif", size=16, color="black"))
	
	layout4_4 = Layout(;
					title_text ="Fig 5. MP Function",
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" Real interest rate (r)", showgrid=true, zeroline=false),
                    xaxis_range = [2.5, 4.5],
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[1 , 5])
	
	p4_4 = Plot([trace4_0, trace4_1, trace4_3, trace4_4], layout4_4)
end;

# ╔═╡ 4b11d361-dab6-4440-b269-499b36737f0d
begin
	p04 =[p4_4 p9_6]
end

# ╔═╡ f029f20a-d065-4211-b71f-18c56bc41a7a
md"""
##### Exercise 7. Supporting cells
"""

# ╔═╡ a1b1866b-3179-4829-a0cf-9bdbdb913c8c
begin
	Y6 = 12.0:0.02:15.0
	
	πs6 = πs_min5 .+ γ5 .*Y6 .+ ρ7            # AS function
	
	trace9_8 = scatter(; x = Y6, y = πs6, mode="lines" , line_color = "Coral", line_width = "3",
			name  = "AS2")	
	
	trace9_9 = scatter(; x = [14.2], y = [1.0], text =["2"], 
					textposition = "top center", name ="Eq2", mode="markers+text", 
					marker_size= "12", marker_color="Coral",
					textfont = attr(family="sans serif", size=16, color="black"))
	
	
	layout9_9= Layout(;
					title_text ="Fig 8. A Positive Temporary Supply Shock",
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" GDP trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [13.6, 14.5],	
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-1 , 4])
	

    p9_9 = Plot([trace9_0,trace9_1,trace9_2, trace9_8, trace9_3, trace9_9], layout9_9)
	
end;

# ╔═╡ 2d8d028a-2709-4ba4-bf95-cf927187c67a
begin
	
	trace4_5 = scatter(; x = [2.5], y = [1.0], text =["2"], 
					textposition = "top center", name ="Eq2", mode="markers+text", 
					marker_size= "12", marker_color="Brown", 
					textfont = attr(family="sans serif", size=16, color="black"))
	
	layout4_5 = Layout(;
					title_text ="Fig 7. MP Function",
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" Real interest rate (r)", showgrid=true, zeroline=false),
                    xaxis_range = [1.5, 4.0],
					xaxis_tickvals = [1.5, 2, 2.5, 3, 3.5, 4],
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-1 , 4])
	
	p4_5 = Plot([trace4_0, trace4_1, trace4_5], layout4_5)
end;

# ╔═╡ 1d36abf0-a3ea-45d1-9ef2-1a8a1fdc50b4
begin
	p05 =[p4_5 p9_9]
end

# ╔═╡ 2b1953d1-4bb8-42c6-98be-c353a44d8857
begin
	Y6_self6 = 12.0:0.01:15.0
	
	πs6_self6 = πs_min5 .+ γ5 .*Y6_self6 .+ ρ7   .+ self_correction7           # AS function
	
	trace9_10 = scatter(; x = Y6_self6, y = πs6_self6, mode="lines" , 
		line_color = "burlywood", line_width = "3",	name  = "AS2")	
	
	trace9_11 = scatter(; x = [14.0], y = [2.0], text =["3"], 
					textposition = "bottom center", name ="Eq3", mode="markers+text", 
					marker_size= "12", marker_color="burlywood", 
					textfont = attr(family="sans serif", size=18, color="black"))
	layout9_10= Layout(;
					title_text ="Fig 10. A Positive Temporary Supply Shock",
					title_x = 0.5,
					hovermode = "x",
                    xaxis=attr(title=" GDP trillion dollars (Y)", showgrid=true, zeroline=false),
                    xaxis_range = [13.6, 14.5],	
                    yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					yaxis_range=[-1 , 4])
	
	

    p9_11 = Plot([trace9_0,trace9_1,trace9_2, trace9_10, trace9_3, trace9_9, trace9_11], layout9_10)
	
end;

# ╔═╡ c435e0de-1b92-4062-a30e-a1da56a91914
begin
	trace4_6 = scatter(; x = [3.0], y = [2.0], text =["3"], 
					textposition = "bottom center", name ="Eq3", mode="markers+text", 
					marker_size= "12", marker_color="Brown", 
					textfont = attr(family="sans serif", size=16, color="black"))
	
	layout4_6= Layout(;
					title_text ="Fig 9. MP Function",
					title_x = 0.5,
					hovermode = "x",
                     xaxis=attr(title=" Real interest rate (r)", showgrid=true, zeroline=false),
                     xaxis_range = [1.5 , 4.0],
					 xaxis_tickvals = [1.5, 2, 2.5, 3, 3.5, 4],
                     yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					 yaxis_range=[-1 , 4])
	
	p4_6 = Plot([trace4_0, trace4_1, trace4_5, trace4_6], layout4_6)
end;

# ╔═╡ 39b9f0db-8735-4d0d-8e75-384bf21c1bc8
begin
	p06 =[p4_6 p9_11]
end

# ╔═╡ 01ce076b-3033-4f1b-acb7-1f775c4ed1e1
md"""
####  Exercise 8. Supporting cells
"""

# ╔═╡ f760841b-8a69-4aa4-a76b-edbf27f7de63
begin
	Y7 = 12.0:0.01:15.0
	
	trace9_12 = scatter(; x = [14.2,14.2] , y = [-7,14] , mode = "line", line_width = "4", name = "Yp2", 
					line_color = "Orange")
	
	πs7 = πs_min5 .+ γ5 .*Y5 .+ ρ5  .+ self_correction8           # AS function
	
	trace9_13 = scatter(; x = Y7, y = πs7, mode="lines" , line_color = "burlywood", 
					line_width = "3", name  = "AS2")	
	
	layout9_13= Layout(;
					title_text ="Fig 12. A Positive Permanent Supply Shock",
					title_x = 0.5,
					hovermode = "x",
                     xaxis=attr(title=" GDP trillion dollars (Y)", showgrid=true, zeroline=false),
                     xaxis_range = [13.6, 14.5],	
                     yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					 yaxis_range=[-1.0 , 4.0])
	

    p9_13 = Plot([trace9_0, trace9_12, trace9_1,trace9_2, trace9_13, trace9_3, trace9_9], layout9_13)
	
end;

# ╔═╡ 88491aa6-3a00-4237-b8a7-a1385b69eccf
begin
	
	trace4_7 = scatter(; x = [2.5], y = [1.0], text =["2"], 
					textposition = "top center", name ="Eq.", mode="markers+text", marker_size= "12",
					marker_color="Brown", textcolor = "Black")
	
	layout4_7 = Layout(; 
					title_text ="Fig 10. MP Function",
					title_x = 0.5,
					hovermode = "x",
                     xaxis=attr(title=" Real interest rate (r)", showgrid=true, zeroline=false),
                     xaxis_range = [1.5, 4.0],
					 xaxis_tickvals = [1.5, 2, 2.5, 3, 3.5, 4],
                     yaxis=attr(title="Rate of inflation (π)", zeroline = false),
					 yaxis_range=[-1 , 4])
	
	p4_7 = Plot([trace4_0, trace4_1, trace4_5], layout4_7)
end;

# ╔═╡ f331c8bc-ab24-4547-b9e9-f1d543916862
begin
	p07 =[p4_7 p9_13]
end

# ╔═╡ 00000000-0000-0000-0000-000000000001
PLUTO_PROJECT_TOML_CONTENTS = """
[deps]
HypertextLiteral = "ac1192a8-f4b3-4bfe-ba22-af5b92cd3ab2"
NLsolve = "2774e3e8-f4cf-5e23-947b-6d7e65073b56"
PlotlyBase = "a03496cd-edff-5a9b-9e67-9cda94a718b5"
PlutoPlotly = "8e989ff0-3d88-8e9f-f020-2b208a939ff0"
PlutoUI = "7f904dfe-b85e-4ff6-b463-dae2292396a8"

[compat]
HypertextLiteral = "~0.9.4"
NLsolve = "~4.5.1"
PlotlyBase = "~0.8.19"
PlutoPlotly = "~0.4.2"
PlutoUI = "~0.7.48"
"""

# ╔═╡ 00000000-0000-0000-0000-000000000002
PLUTO_MANIFEST_TOML_CONTENTS = """
# This file is machine-generated - editing it directly is not advised

julia_version = "1.10.0"
manifest_format = "2.0"
project_hash = "a98b0bfc4256ab8c9ab1ee2050cc534fe1163447"

[[deps.AbstractPlutoDingetjes]]
deps = ["Pkg"]
git-tree-sha1 = "8eaf9f1b4921132a4cff3f36a1d9ba923b14a481"
uuid = "6e696c72-6542-2067-7265-42206c756150"
version = "1.1.4"

[[deps.Adapt]]
deps = ["LinearAlgebra", "Requires"]
git-tree-sha1 = "76289dc51920fdc6e0013c872ba9551d54961c24"
uuid = "79e6a3ab-5dfb-504d-930d-738a2a938a0e"
version = "3.6.2"
weakdeps = ["StaticArrays"]

    [deps.Adapt.extensions]
    AdaptStaticArraysExt = "StaticArrays"

[[deps.ArgTools]]
uuid = "0dad84c5-d112-42e6-8d28-ef12dabb789f"
version = "1.1.1"

[[deps.ArrayInterface]]
deps = ["Adapt", "LinearAlgebra", "Requires", "SparseArrays", "SuiteSparse"]
git-tree-sha1 = "917286faa2abb288796e75b88ca67edc016f3219"
uuid = "4fba245c-0d91-5ea0-9b3e-6abc04ee57a9"
version = "7.4.5"

    [deps.ArrayInterface.extensions]
    ArrayInterfaceBandedMatricesExt = "BandedMatrices"
    ArrayInterfaceBlockBandedMatricesExt = "BlockBandedMatrices"
    ArrayInterfaceCUDAExt = "CUDA"
    ArrayInterfaceGPUArraysCoreExt = "GPUArraysCore"
    ArrayInterfaceStaticArraysCoreExt = "StaticArraysCore"
    ArrayInterfaceTrackerExt = "Tracker"

    [deps.ArrayInterface.weakdeps]
    BandedMatrices = "aae01518-5342-5314-be14-df237901396f"
    BlockBandedMatrices = "ffab5731-97b5-5995-9138-79e8c1846df0"
    CUDA = "052768ef-5323-5732-b1bb-66c8b64840ba"
    GPUArraysCore = "46192b85-c4d5-4398-a991-12ede77f4527"
    StaticArraysCore = "1e83bf80-4336-4d27-bf5d-d5a4f845583c"
    Tracker = "9f7883ad-71c0-57eb-9f7f-b5c9e6d3789c"

[[deps.Artifacts]]
uuid = "56f22d72-fd6d-98f1-02f0-08ddc0907c33"

[[deps.Base64]]
uuid = "2a0f44e3-6c83-55bd-87e4-b1978d98bd5f"

[[deps.BaseDirs]]
git-tree-sha1 = "1c9b6f39f40dba0ef22244a175e2d4e42c8f6ee7"
uuid = "18cc8868-cbac-4acf-b575-c8ff214dc66f"
version = "1.2.0"

[[deps.ColorSchemes]]
deps = ["ColorTypes", "ColorVectorSpace", "Colors", "FixedPointNumbers", "PrecompileTools", "Random"]
git-tree-sha1 = "be6ab11021cd29f0344d5c4357b163af05a48cba"
uuid = "35d6a980-a343-548e-a6ea-1d62b119f2f4"
version = "3.21.0"

[[deps.ColorTypes]]
deps = ["FixedPointNumbers", "Random"]
git-tree-sha1 = "eb7f0f8307f71fac7c606984ea5fb2817275d6e4"
uuid = "3da002f7-5984-5a60-b8a6-cbb66c0b333f"
version = "0.11.4"

[[deps.ColorVectorSpace]]
deps = ["ColorTypes", "FixedPointNumbers", "LinearAlgebra", "SpecialFunctions", "Statistics", "TensorCore"]
git-tree-sha1 = "600cc5508d66b78aae350f7accdb58763ac18589"
uuid = "c3611d14-8923-5661-9e6a-0046d554d3a4"
version = "0.9.10"

[[deps.Colors]]
deps = ["ColorTypes", "FixedPointNumbers", "Reexport"]
git-tree-sha1 = "fc08e5930ee9a4e03f84bfb5211cb54e7769758a"
uuid = "5ae59095-9a9b-59fe-a467-6f913c188581"
version = "0.12.10"

[[deps.CommonSubexpressions]]
deps = ["MacroTools", "Test"]
git-tree-sha1 = "7b8a93dba8af7e3b42fecabf646260105ac373f7"
uuid = "bbf7d656-a473-5ed7-a52c-81e309532950"
version = "0.3.0"

[[deps.CompilerSupportLibraries_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "e66e0078-7015-5450-92f7-15fbd957f2ae"
version = "1.0.5+1"

[[deps.ConstructionBase]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "738fec4d684a9a6ee9598a8bfee305b26831f28c"
uuid = "187b0558-2788-49d3-abe0-74a17ed4e7c9"
version = "1.5.2"

    [deps.ConstructionBase.extensions]
    ConstructionBaseIntervalSetsExt = "IntervalSets"
    ConstructionBaseStaticArraysExt = "StaticArrays"

    [deps.ConstructionBase.weakdeps]
    IntervalSets = "8197267c-284f-5f27-9208-e0e47529a953"
    StaticArrays = "90137ffa-7385-5640-81b9-e52037218182"

[[deps.Dates]]
deps = ["Printf"]
uuid = "ade2ca70-3891-5945-98fb-dc099432e06a"

[[deps.DelimitedFiles]]
deps = ["Mmap"]
git-tree-sha1 = "9e2f36d3c96a820c678f2f1f1782582fcf685bae"
uuid = "8bb1440f-4735-579b-a4ab-409b98df4dab"
version = "1.9.1"

[[deps.DiffResults]]
deps = ["StaticArraysCore"]
git-tree-sha1 = "782dd5f4561f5d267313f23853baaaa4c52ea621"
uuid = "163ba53b-c6d8-5494-b064-1a9d43ac40c5"
version = "1.1.0"

[[deps.DiffRules]]
deps = ["IrrationalConstants", "LogExpFunctions", "NaNMath", "Random", "SpecialFunctions"]
git-tree-sha1 = "a4ad7ef19d2cdc2eff57abbbe68032b1cd0bd8f8"
uuid = "b552c78f-8df3-52c6-915a-8e097449b14b"
version = "1.13.0"

[[deps.Distances]]
deps = ["LinearAlgebra", "SparseArrays", "Statistics", "StatsAPI"]
git-tree-sha1 = "49eba9ad9f7ead780bfb7ee319f962c811c6d3b2"
uuid = "b4f34e82-e78d-54a5-968a-f98e89d6e8f7"
version = "0.10.8"

[[deps.Distributed]]
deps = ["Random", "Serialization", "Sockets"]
uuid = "8ba89e20-285c-5b6f-9357-94700520ee1b"

[[deps.DocStringExtensions]]
deps = ["LibGit2"]
git-tree-sha1 = "2fb1e02f2b635d0845df5d7c167fec4dd739b00d"
uuid = "ffbed154-4ef7-542d-bbb7-c09d3a79fcae"
version = "0.9.3"

[[deps.Downloads]]
deps = ["ArgTools", "FileWatching", "LibCURL", "NetworkOptions"]
uuid = "f43a241f-c20a-4ad4-852c-f6b1247861c6"
version = "1.6.0"

[[deps.FileWatching]]
uuid = "7b1f6079-737a-58dc-b8bc-7a2ca5c1b5ee"

[[deps.FiniteDiff]]
deps = ["ArrayInterface", "LinearAlgebra", "Requires", "Setfield", "SparseArrays", "StaticArrays"]
git-tree-sha1 = "6604e18a0220650dbbea7854938768f15955dd8e"
uuid = "6a86dc24-6348-571c-b903-95158fe2bd41"
version = "2.20.0"

[[deps.FixedPointNumbers]]
deps = ["Statistics"]
git-tree-sha1 = "335bfdceacc84c5cdf16aadc768aa5ddfc5383cc"
uuid = "53c48c17-4a7d-5ca2-90c5-79b7896eea93"
version = "0.8.4"

[[deps.ForwardDiff]]
deps = ["CommonSubexpressions", "DiffResults", "DiffRules", "LinearAlgebra", "LogExpFunctions", "NaNMath", "Preferences", "Printf", "Random", "SpecialFunctions"]
git-tree-sha1 = "00e252f4d706b3d55a8863432e742bf5717b498d"
uuid = "f6369f11-7733-5829-9624-2563aa707210"
version = "0.10.35"
weakdeps = ["StaticArrays"]

    [deps.ForwardDiff.extensions]
    ForwardDiffStaticArraysExt = "StaticArrays"

[[deps.Future]]
deps = ["Random"]
uuid = "9fa8497b-333b-5362-9e8d-4d0656e87820"

[[deps.Hyperscript]]
deps = ["Test"]
git-tree-sha1 = "8d511d5b81240fc8e6802386302675bdf47737b9"
uuid = "47d2ed2b-36de-50cf-bf87-49c2cf4b8b91"
version = "0.0.4"

[[deps.HypertextLiteral]]
deps = ["Tricks"]
git-tree-sha1 = "c47c5fa4c5308f27ccaac35504858d8914e102f9"
uuid = "ac1192a8-f4b3-4bfe-ba22-af5b92cd3ab2"
version = "0.9.4"

[[deps.IOCapture]]
deps = ["Logging", "Random"]
git-tree-sha1 = "d75853a0bdbfb1ac815478bacd89cd27b550ace6"
uuid = "b5f81e59-6552-4d32-b1f0-c071b021bf89"
version = "0.2.3"

[[deps.InteractiveUtils]]
deps = ["Markdown"]
uuid = "b77e0a4c-d291-57a0-90e8-8db25a27a240"

[[deps.IrrationalConstants]]
git-tree-sha1 = "630b497eafcc20001bba38a4651b327dcfc491d2"
uuid = "92d709cd-6900-40b7-9082-c6be49f344b6"
version = "0.2.2"

[[deps.JLLWrappers]]
deps = ["Preferences"]
git-tree-sha1 = "abc9885a7ca2052a736a600f7fa66209f96506e1"
uuid = "692b3bcd-3c85-4b1f-b108-f13ce0eb3210"
version = "1.4.1"

[[deps.JSON]]
deps = ["Dates", "Mmap", "Parsers", "Unicode"]
git-tree-sha1 = "31e996f0a15c7b280ba9f76636b3ff9e2ae58c9a"
uuid = "682c06a0-de6a-54ab-a142-c8b1cf79cde6"
version = "0.21.4"

[[deps.LaTeXStrings]]
git-tree-sha1 = "f2355693d6778a178ade15952b7ac47a4ff97996"
uuid = "b964fa9f-0449-5b57-a5c2-d3ea65f4040f"
version = "1.3.0"

[[deps.LibCURL]]
deps = ["LibCURL_jll", "MozillaCACerts_jll"]
uuid = "b27032c2-a3e7-50c8-80cd-2d36dbcbfd21"
version = "0.6.4"

[[deps.LibCURL_jll]]
deps = ["Artifacts", "LibSSH2_jll", "Libdl", "MbedTLS_jll", "Zlib_jll", "nghttp2_jll"]
uuid = "deac9b47-8bc7-5906-a0fe-35ac56dc84c0"
version = "8.4.0+0"

[[deps.LibGit2]]
deps = ["Base64", "LibGit2_jll", "NetworkOptions", "Printf", "SHA"]
uuid = "76f85450-5226-5b5a-8eaa-529ad045b433"

[[deps.LibGit2_jll]]
deps = ["Artifacts", "LibSSH2_jll", "Libdl", "MbedTLS_jll"]
uuid = "e37daf67-58a4-590a-8e99-b0245dd2ffc5"
version = "1.6.4+0"

[[deps.LibSSH2_jll]]
deps = ["Artifacts", "Libdl", "MbedTLS_jll"]
uuid = "29816b5a-b9ab-546f-933c-edad1886dfa8"
version = "1.11.0+1"

[[deps.Libdl]]
uuid = "8f399da3-3557-5675-b5ff-fb832c97cbdb"

[[deps.LineSearches]]
deps = ["LinearAlgebra", "NLSolversBase", "NaNMath", "Parameters", "Printf"]
git-tree-sha1 = "7bbea35cec17305fc70a0e5b4641477dc0789d9d"
uuid = "d3d80556-e9d4-5f37-9878-2ab0fcc64255"
version = "7.2.0"

[[deps.LinearAlgebra]]
deps = ["Libdl", "OpenBLAS_jll", "libblastrampoline_jll"]
uuid = "37e2e46d-f89d-539d-b4ee-838fcccc9c8e"

[[deps.LogExpFunctions]]
deps = ["DocStringExtensions", "IrrationalConstants", "LinearAlgebra"]
git-tree-sha1 = "0a1b7c2863e44523180fdb3146534e265a91870b"
uuid = "2ab3a3ac-af41-5b50-aa03-7779005ae688"
version = "0.3.23"

    [deps.LogExpFunctions.extensions]
    LogExpFunctionsChainRulesCoreExt = "ChainRulesCore"
    LogExpFunctionsChangesOfVariablesExt = "ChangesOfVariables"
    LogExpFunctionsInverseFunctionsExt = "InverseFunctions"

    [deps.LogExpFunctions.weakdeps]
    ChainRulesCore = "d360d2e6-b24c-11e9-a2a3-2a2ae2dbcce4"
    ChangesOfVariables = "9e997f8a-9a97-42d5-a9f1-ce6bfc15e2c0"
    InverseFunctions = "3587e190-3f89-42d0-90ee-14403ec27112"

[[deps.Logging]]
uuid = "56ddb016-857b-54e1-b83d-db4d58db5568"

[[deps.MIMEs]]
git-tree-sha1 = "65f28ad4b594aebe22157d6fac869786a255b7eb"
uuid = "6c6e2e6c-3030-632d-7369-2d6c69616d65"
version = "0.1.4"

[[deps.MacroTools]]
deps = ["Markdown", "Random"]
git-tree-sha1 = "42324d08725e200c23d4dfb549e0d5d89dede2d2"
uuid = "1914dd2f-81c6-5fcd-8719-6d5c9610ff09"
version = "0.5.10"

[[deps.Markdown]]
deps = ["Base64"]
uuid = "d6f4376e-aef5-505a-96c1-9c027394607a"

[[deps.MbedTLS_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "c8ffd9c3-330d-5841-b78e-0817d7145fa1"
version = "2.28.2+1"

[[deps.Mmap]]
uuid = "a63ad114-7e13-5084-954f-fe012c677804"

[[deps.MozillaCACerts_jll]]
uuid = "14a3606d-f60d-562e-9121-12d972cd8159"
version = "2023.1.10"

[[deps.NLSolversBase]]
deps = ["DiffResults", "Distributed", "FiniteDiff", "ForwardDiff"]
git-tree-sha1 = "a0b464d183da839699f4c79e7606d9d186ec172c"
uuid = "d41bc354-129a-5804-8e4c-c37616107c6c"
version = "7.8.3"

[[deps.NLsolve]]
deps = ["Distances", "LineSearches", "LinearAlgebra", "NLSolversBase", "Printf", "Reexport"]
git-tree-sha1 = "019f12e9a1a7880459d0173c182e6a99365d7ac1"
uuid = "2774e3e8-f4cf-5e23-947b-6d7e65073b56"
version = "4.5.1"

[[deps.NaNMath]]
deps = ["OpenLibm_jll"]
git-tree-sha1 = "0877504529a3e5c3343c6f8b4c0381e57e4387e4"
uuid = "77ba4419-2d1f-58cd-9bb1-8ffee604a2e3"
version = "1.0.2"

[[deps.NetworkOptions]]
uuid = "ca575930-c2e3-43a9-ace4-1e988b2c1908"
version = "1.2.0"

[[deps.OpenBLAS_jll]]
deps = ["Artifacts", "CompilerSupportLibraries_jll", "Libdl"]
uuid = "4536629a-c528-5b80-bd46-f80d51c5b363"
version = "0.3.23+2"

[[deps.OpenLibm_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "05823500-19ac-5b8b-9628-191a04bc5112"
version = "0.8.1+2"

[[deps.OpenSpecFun_jll]]
deps = ["Artifacts", "CompilerSupportLibraries_jll", "JLLWrappers", "Libdl", "Pkg"]
git-tree-sha1 = "13652491f6856acfd2db29360e1bbcd4565d04f1"
uuid = "efe28fd5-8261-553b-a9e1-b2916fc3738e"
version = "0.5.5+0"

[[deps.OrderedCollections]]
git-tree-sha1 = "d321bf2de576bf25ec4d3e4360faca399afca282"
uuid = "bac558e1-5e72-5ebc-8fee-abe8a469f55d"
version = "1.6.0"

[[deps.Parameters]]
deps = ["OrderedCollections", "UnPack"]
git-tree-sha1 = "34c0e9ad262e5f7fc75b10a9952ca7692cfc5fbe"
uuid = "d96e819e-fc66-5662-9728-84c9c7592b0a"
version = "0.12.3"

[[deps.Parsers]]
deps = ["Dates", "PrecompileTools", "UUIDs"]
git-tree-sha1 = "a5aef8d4a6e8d81f171b2bd4be5265b01384c74c"
uuid = "69de0a69-1ddd-5017-9359-2bf0b02dc9f0"
version = "2.5.10"

[[deps.Pkg]]
deps = ["Artifacts", "Dates", "Downloads", "FileWatching", "LibGit2", "Libdl", "Logging", "Markdown", "Printf", "REPL", "Random", "SHA", "Serialization", "TOML", "Tar", "UUIDs", "p7zip_jll"]
uuid = "44cfe95a-1eb2-52ea-b672-e2afdf69b78f"
version = "1.10.0"

[[deps.PlotlyBase]]
deps = ["ColorSchemes", "Dates", "DelimitedFiles", "DocStringExtensions", "JSON", "LaTeXStrings", "Logging", "Parameters", "Pkg", "REPL", "Requires", "Statistics", "UUIDs"]
git-tree-sha1 = "56baf69781fc5e61607c3e46227ab17f7040ffa2"
uuid = "a03496cd-edff-5a9b-9e67-9cda94a718b5"
version = "0.8.19"

[[deps.PlutoPlotly]]
deps = ["AbstractPlutoDingetjes", "BaseDirs", "Colors", "Dates", "Downloads", "HypertextLiteral", "InteractiveUtils", "LaTeXStrings", "Markdown", "Pkg", "PlotlyBase", "Reexport", "TOML"]
git-tree-sha1 = "d169dae7b340a1b0ca50ef359ed100f07ad677a4"
uuid = "8e989ff0-3d88-8e9f-f020-2b208a939ff0"
version = "0.4.2"

    [deps.PlutoPlotly.extensions]
    PlotlyKaleidoExt = "PlotlyKaleido"
    UnitfulExt = "Unitful"

    [deps.PlutoPlotly.weakdeps]
    PlotlyKaleido = "f2990250-8cf9-495f-b13a-cce12b45703c"
    Unitful = "1986cc42-f94f-5a68-af5c-568840ba703d"

[[deps.PlutoUI]]
deps = ["AbstractPlutoDingetjes", "Base64", "ColorTypes", "Dates", "FixedPointNumbers", "Hyperscript", "HypertextLiteral", "IOCapture", "InteractiveUtils", "JSON", "Logging", "MIMEs", "Markdown", "Random", "Reexport", "URIs", "UUIDs"]
git-tree-sha1 = "b478a748be27bd2f2c73a7690da219d0844db305"
uuid = "7f904dfe-b85e-4ff6-b463-dae2292396a8"
version = "0.7.51"

[[deps.PrecompileTools]]
deps = ["Preferences"]
git-tree-sha1 = "259e206946c293698122f63e2b513a7c99a244e8"
uuid = "aea7be01-6a6a-4083-8856-8a6e6704d82a"
version = "1.1.1"

[[deps.Preferences]]
deps = ["TOML"]
git-tree-sha1 = "7eb1686b4f04b82f96ed7a4ea5890a4f0c7a09f1"
uuid = "21216c6a-2e73-6563-6e65-726566657250"
version = "1.4.0"

[[deps.Printf]]
deps = ["Unicode"]
uuid = "de0858da-6303-5e67-8744-51eddeeeb8d7"

[[deps.REPL]]
deps = ["InteractiveUtils", "Markdown", "Sockets", "Unicode"]
uuid = "3fa0cd96-eef1-5676-8a61-b3b8758bbffb"

[[deps.Random]]
deps = ["SHA"]
uuid = "9a3f8284-a2c9-5f02-9a11-845980a1fd5c"

[[deps.Reexport]]
git-tree-sha1 = "45e428421666073eab6f2da5c9d310d99bb12f9b"
uuid = "189a3867-3050-52da-a836-e630ba90ab69"
version = "1.2.2"

[[deps.Requires]]
deps = ["UUIDs"]
git-tree-sha1 = "838a3a4188e2ded87a4f9f184b4b0d78a1e91cb7"
uuid = "ae029012-a4dd-5104-9daa-d747884805df"
version = "1.3.0"

[[deps.SHA]]
uuid = "ea8e919c-243c-51af-8825-aaa63cd721ce"
version = "0.7.0"

[[deps.Serialization]]
uuid = "9e88b42a-f829-5b0c-bbe9-9e923198166b"

[[deps.Setfield]]
deps = ["ConstructionBase", "Future", "MacroTools", "StaticArraysCore"]
git-tree-sha1 = "e2cc6d8c88613c05e1defb55170bf5ff211fbeac"
uuid = "efcf1570-3423-57d1-acb7-fd33fddbac46"
version = "1.1.1"

[[deps.Sockets]]
uuid = "6462fe0b-24de-5631-8697-dd941f90decc"

[[deps.SparseArrays]]
deps = ["Libdl", "LinearAlgebra", "Random", "Serialization", "SuiteSparse_jll"]
uuid = "2f01184e-e22b-5df5-ae63-d93ebab69eaf"
version = "1.10.0"

[[deps.SpecialFunctions]]
deps = ["IrrationalConstants", "LogExpFunctions", "OpenLibm_jll", "OpenSpecFun_jll"]
git-tree-sha1 = "ef28127915f4229c971eb43f3fc075dd3fe91880"
uuid = "276daf66-3868-5448-9aa4-cd146d93841b"
version = "2.2.0"

    [deps.SpecialFunctions.extensions]
    SpecialFunctionsChainRulesCoreExt = "ChainRulesCore"

    [deps.SpecialFunctions.weakdeps]
    ChainRulesCore = "d360d2e6-b24c-11e9-a2a3-2a2ae2dbcce4"

[[deps.StaticArrays]]
deps = ["LinearAlgebra", "Random", "StaticArraysCore", "Statistics"]
git-tree-sha1 = "8982b3607a212b070a5e46eea83eb62b4744ae12"
uuid = "90137ffa-7385-5640-81b9-e52037218182"
version = "1.5.25"

[[deps.StaticArraysCore]]
git-tree-sha1 = "6b7ba252635a5eff6a0b0664a41ee140a1c9e72a"
uuid = "1e83bf80-4336-4d27-bf5d-d5a4f845583c"
version = "1.4.0"

[[deps.Statistics]]
deps = ["LinearAlgebra", "SparseArrays"]
uuid = "10745b16-79ce-11e8-11f9-7d13ad32a3b2"
version = "1.10.0"

[[deps.StatsAPI]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "45a7769a04a3cf80da1c1c7c60caf932e6f4c9f7"
uuid = "82ae8749-77ed-4fe6-ae5f-f523153014b0"
version = "1.6.0"

[[deps.SuiteSparse]]
deps = ["Libdl", "LinearAlgebra", "Serialization", "SparseArrays"]
uuid = "4607b0f0-06f3-5cda-b6b1-a6196a1729e9"

[[deps.SuiteSparse_jll]]
deps = ["Artifacts", "Libdl", "libblastrampoline_jll"]
uuid = "bea87d4a-7f5b-5778-9afe-8cc45184846c"
version = "7.2.1+1"

[[deps.TOML]]
deps = ["Dates"]
uuid = "fa267f1f-6049-4f14-aa54-33bafae1ed76"
version = "1.0.3"

[[deps.Tar]]
deps = ["ArgTools", "SHA"]
uuid = "a4e569a6-e804-4fa4-b0f3-eef7a1d5b13e"
version = "1.10.0"

[[deps.TensorCore]]
deps = ["LinearAlgebra"]
git-tree-sha1 = "1feb45f88d133a655e001435632f019a9a1bcdb6"
uuid = "62fd8b95-f654-4bbd-a8a5-9c27f68ccd50"
version = "0.1.1"

[[deps.Test]]
deps = ["InteractiveUtils", "Logging", "Random", "Serialization"]
uuid = "8dfed614-e22c-5e08-85e1-65c5234f0b40"

[[deps.Tricks]]
git-tree-sha1 = "aadb748be58b492045b4f56166b5188aa63ce549"
uuid = "410a4b4d-49e4-4fbc-ab6d-cb71b17b3775"
version = "0.1.7"

[[deps.URIs]]
git-tree-sha1 = "074f993b0ca030848b897beff716d93aca60f06a"
uuid = "5c2747f8-b7ea-4ff2-ba2e-563bfd36b1d4"
version = "1.4.2"

[[deps.UUIDs]]
deps = ["Random", "SHA"]
uuid = "cf7118a7-6976-5b1a-9a39-7adc72f591a4"

[[deps.UnPack]]
git-tree-sha1 = "387c1f73762231e86e0c9c5443ce3b4a0a9a0c2b"
uuid = "3a884ed6-31ef-47d7-9d2a-63182c4928ed"
version = "1.0.2"

[[deps.Unicode]]
uuid = "4ec0a83e-493e-50e2-b9ac-8f72acf5a8f5"

[[deps.Zlib_jll]]
deps = ["Libdl"]
uuid = "83775a58-1f1d-513f-b197-d71354ab007a"
version = "1.2.13+1"

[[deps.libblastrampoline_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "8e850b90-86db-534c-a0d3-1478176c7d93"
version = "5.8.0+1"

[[deps.nghttp2_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "8e850ede-7688-5339-a07c-302acd2aaf8d"
version = "1.52.0+1"

[[deps.p7zip_jll]]
deps = ["Artifacts", "Libdl"]
uuid = "3f19e933-33d8-53b3-aaab-bd5110c3b7a0"
version = "17.4.0+2"
"""

# ╔═╡ Cell order:
# ╟─943edb36-acc8-4b2a-94ab-c544f9eb279b
# ╟─1245aef9-18ce-42f5-af82-c2e6cce70798
# ╟─4618a663-f77e-4ccc-9b00-e84dbd5beb34
# ╠═a145e2fe-a903-11eb-160f-df7ea83fa3e6
# ╟─74de9f66-d5b4-4e0f-a75d-5177b1842191
# ╟─69d5adb8-c5fd-4fd9-875d-cc4c25af0125
# ╟─0bc2eb14-3b5a-4203-82dd-3ef2044a2c93
# ╟─5999a598-0408-44f1-bd33-c4d0fa5a6006
# ╟─5ceac821-7004-4764-b2ee-b9e2aa0f6fdf
# ╟─450dec57-18a3-4031-bf36-36a422d0fd34
# ╟─eb74f385-1688-45ea-8ad1-11bce1e48f87
# ╟─c90e721d-f4ca-473c-8a7c-7159d66d81cf
# ╟─4b6af178-725d-4841-8d62-102c561428c6
# ╟─bd22c100-271d-4496-a55f-792f0f92117f
# ╟─21d4988a-e438-4562-bc8f-a1d847020e25
# ╟─afeda154-0ce5-4e1b-9e12-24420dd72681
# ╟─08203cfc-1ede-432b-b81c-f0a5cbaa5816
# ╟─40913213-c3f7-4dd7-9ffa-c1390f80c099
# ╟─c49227b4-af6d-4c5b-a2fb-ffd15b1c84b8
# ╟─b6e384ad-f8fb-434c-944a-91ac9f729068
# ╟─ec759c26-25d0-4554-96ea-665f6b694204
# ╟─c38dbe18-a85a-4960-9c99-674196e0526d
# ╟─cb0d6593-5ca4-4afd-bddc-88506c4cf477
# ╟─35612933-4d9a-4b88-b40f-3a2eec3a20fa
# ╟─6b39a08d-9f0d-4e46-9f63-549d7eb15c05
# ╟─d72389b4-b317-4d1a-928a-c002822ed785
# ╟─f20bd50f-8096-4169-b4ed-bd107fa2537a
# ╟─add07024-b7eb-445d-b4f4-6a6757c2ecd3
# ╟─8e2203e6-6677-47b9-8032-e9c63c0f41bb
# ╟─0fe4de49-3687-4900-a691-334cca6dd3c6
# ╠═a77a222e-aba3-4ac6-a5b0-a7551e3ccce4
# ╟─74ee6d92-ef34-47ce-8d57-39d41474a11d
# ╟─3aba8dac-7fa0-4193-9f41-ff8d9a49230f
# ╟─40d80d26-e808-43bf-833e-d1bb07b57630
# ╠═1b2dba45-7fbc-4658-9a02-1c54511f650a
# ╠═6a9080ad-2117-4e8e-86b4-4c3a737b989b
# ╟─fc550324-0ffd-4039-b92e-67f12b6b8c90
# ╟─6e92b539-a91d-410f-a895-8d4b51b5257b
# ╟─7ae85983-ee8e-4dd3-a7bf-474aaf74863c
# ╟─a54b4a9b-a752-454f-af38-87ec1115512a
# ╟─445f88ea-3c01-4939-a2bc-a1c139213b17
# ╟─9b54c17b-e835-4478-95ae-a9e2d5de9f59
# ╟─7f7ca57b-5774-4184-8026-32ad0f56cb39
# ╟─7e47b3bc-a45c-4d84-9a58-d4f01d6ba99f
# ╟─5c2ce460-bd7a-4355-8b11-d8e6896d973d
# ╟─704145a9-ef2e-48ad-bbe2-b6bc750d62fc
# ╟─13b03571-e332-46f7-83d7-4a41fbcca0b5
# ╟─0941b1d5-b354-4857-9264-fcd2744e03a6
# ╟─63fb8be4-f6ce-457b-8d0c-b359f959f5a6
# ╟─4b11d361-dab6-4440-b269-499b36737f0d
# ╟─979c128b-76ed-4c28-b3ad-ffbbac481414
# ╟─e69deaa4-bb1f-454b-9296-598a9b9271a0
# ╟─1072c4ef-b41f-4de8-a64d-3cdaecf8949d
# ╟─1d0765df-9ee8-4e65-a0d1-bc3e54940846
# ╠═0252b84b-8411-4145-81ee-3e90892d859f
# ╠═e6262829-bfe3-4030-9158-28a37c13fc1a
# ╟─9cefbcc6-397b-48d9-810b-05937873184a
# ╟─3aca9c62-a1e3-4478-a8a5-29d19535ad75
# ╟─dcd13560-0f73-4aaa-b59a-b7961d8cdc63
# ╟─7f67d656-bb55-4097-ba49-10140f9b3502
# ╟─fe1e6cbc-db87-40ac-836d-68069615c133
# ╟─22fd1017-4015-407d-bd79-188a763e87a4
# ╟─1d36abf0-a3ea-45d1-9ef2-1a8a1fdc50b4
# ╟─f21a5ae9-7887-4cf1-83f9-f1f0a0b3d5b3
# ╟─7beabfcd-9cbb-4eac-8bdb-298b60f541ac
# ╟─28052403-f02e-41dc-ba74-e42d88f3d494
# ╟─70e7a7ef-d49d-417e-8f87-ed9870857b45
# ╟─db702f28-e3e7-4d14-9209-1cbe2917247b
# ╟─39b9f0db-8735-4d0d-8e75-384bf21c1bc8
# ╟─5859e1fa-f4ef-42b7-a3fd-5085cd64161c
# ╟─933a7956-1037-401e-a0cd-e42ec8eeec2d
# ╟─ec34cbc5-fda5-4792-adc8-3bb0d02a7f22
# ╟─83c030a3-28bc-419f-968b-62ce9ab0a1e4
# ╟─ab9daba1-be70-4e7f-8304-639db1c16d2c
# ╟─f331c8bc-ab24-4547-b9e9-f1d543916862
# ╟─79d2fb58-371b-4720-976c-d5f6a70e46c6
# ╟─a8bfdb49-6a0a-448a-b84e-b5040f8a40c9
# ╟─df3e386a-66f1-4525-b09d-a605c24aff21
# ╟─4a1e9746-51d3-4981-b685-2d1545fb2a07
# ╟─15c7a983-f8d3-44a5-a08a-7426dcee7639
# ╟─e1ad4f38-80cf-4730-9f5e-1a0c021becff
# ╟─34f82c93-1bad-4635-8e5f-3e9960657429
# ╟─6b4249b9-8d60-4547-b416-fe2a21c8f33c
# ╟─26fe310e-9ed8-4d09-bb82-a5bd39193dde
# ╟─63e8392d-c2b3-4a1a-b9f1-2acffe23ecb4
# ╟─3bed5d29-9973-4990-961a-53e53451854e
# ╟─de32bd19-9ef4-45f2-96cd-3a9675d9527d
# ╠═9fa87191-7c90-4738-a45a-acd929c8bd1b
# ╟─31cef45f-d6ea-4c0d-b58f-11ae0988a001
# ╟─18101821-af97-41b3-b77e-6ff28ef91568
# ╟─c2eeacf8-99f0-4a5e-83ac-7bcc6f0e5f22
# ╟─45c90777-16b2-4359-9afa-31fdaf23fd73
# ╟─99b637d3-af40-4132-aa5b-d0d386b8d11a
# ╟─0ed308d6-1457-4571-9898-d6fe23ca827f
# ╟─1f24f76d-6f4e-4031-8d62-41b0ec351a2c
# ╟─62b870d7-80a7-46ea-b784-579d5ad289c2
# ╟─43e8fd65-2d3a-41bc-a8d6-44cf412318ed
# ╟─955e1066-8468-4553-b834-f21116d4a594
# ╟─df2a5996-55a7-4883-ac2f-59d4cce2c129
# ╟─e1fc276a-db60-4de2-b21e-4e6bfcdbe6e2
# ╟─f029f20a-d065-4211-b71f-18c56bc41a7a
# ╟─a1b1866b-3179-4829-a0cf-9bdbdb913c8c
# ╟─2d8d028a-2709-4ba4-bf95-cf927187c67a
# ╟─2b1953d1-4bb8-42c6-98be-c353a44d8857
# ╟─c435e0de-1b92-4062-a30e-a1da56a91914
# ╟─01ce076b-3033-4f1b-acb7-1f775c4ed1e1
# ╟─f760841b-8a69-4aa4-a76b-edbf27f7de63
# ╟─88491aa6-3a00-4237-b8a7-a1385b69eccf
# ╟─00000000-0000-0000-0000-000000000001
# ╟─00000000-0000-0000-0000-000000000002
